#include <fstream>
#include <string>
#include <QObject>
#include "imx6.h"

using namespace std;

Imx6::Imx6(QObject *parent) : QObject(parent)
{
}

Imx6::~Imx6()
{
}

void Imx6::getCurrentTemperature()
{
    string ifile;
    string val;
    string preparedTemp;
    double temperature;
    char buffer [50];

#if defined(Q_OS_LINUX) || (defined(Q_OS_UNIX) && !defined(Q_OS_OSX))
    ifile = "/sys/class/thermal/thermal_zone0/temp";
    ifstream temperatureFile ("/sys/class/thermal/thermal_zone0/temp");
    temperatureFile >> val;
    temperatureFile.close();
#elif defined(Q_OS_MAC) || defined(Q_OS_WIN) || defined(Q_OS_OSX)
    val = "54321";
#endif

    temperature = std::stod(val);
    temperature /= 1000;

    QChar ch(0x00B0);
    QString s="";
    s.append(ch);
    s.append("C");
    string celsius = s.toStdString();

    sprintf(buffer, "%.0f %s", temperature, celsius.c_str());

    emit temperatureUpdate(buffer);
}

int Imx6::getRedLedStatus()
{
    string val;
    QString status;

#if defined(Q_OS_LINUX) || (defined(Q_OS_UNIX) && !defined(Q_OS_OSX))
    ifstream led("/sys/class/leds/red-led/brightness");
    led >> val;
    led.close();
#elif defined(Q_OS_MAC) || defined(Q_OS_WIN) || defined(Q_OS_OSX)
    val = "0";
#endif

    if (stoi(val) == 1)
        status = "On";
    else if (stoi(val) == 0)
        status = "Off";
    else
        status = "ERR";

    emit redLedStatusUpdate(status);

    return stoi(val);
}

void Imx6::setRedLed(int isOn)
{
    QString status;

#if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
    ofstream led("/sys/class/leds/red-led/brightness");
    led << isOn;
    led.close();
#endif

    if (this->getRedLedStatus() == 1)
        status = "On";
    else
        status = "Off";

    emit redLedStatusUpdate(status);
}

void Imx6::toggleRedLed()
{
    int status;

    status = this->getRedLedStatus();
    if(status == 1)
        this->setRedLed(0);
    else
        this->setRedLed(1);
}
